@@ -1,3 +1,4 @@
+use core::cmp::Ordering;
 use crate::{Key, KeyExt, KeyRef};
 use core::ops::Deref;
 use core::slice;
@@ -6,7 +7,7 @@ use core::slice;
 /// This struct is unsafe, because it does not promise the raw pointer always valid.
 ///
 /// [`Key`]: struct.Key.html
-#[derive(Copy, Clone, Eq, PartialEq)]
+#[derive(Debug, Copy, Clone)]
 pub struct RawKeyPointer {
     ptr: *const u8,
     l: u32,
@@ -64,3 +65,27 @@ impl KeyExt for RawKeyPointer {
         self
     }
 }
+
+impl PartialEq<RawKeyPointer> for RawKeyPointer {
+    fn eq(&self, other: &RawKeyPointer) -> bool {
+        self.ptr.eq(&other.ptr)
+    }
+}
+
+impl Eq for RawKeyPointer {}
+
+impl PartialOrd<RawKeyPointer> for RawKeyPointer {
+    fn partial_cmp(&self, other: &RawKeyPointer) -> Option<Ordering> {
+        unsafe {
+            self.as_key_ref().partial_cmp(&other.as_key_ref())
+        }
+    }
+}
+
+impl Ord for RawKeyPointer {
+    fn cmp(&self, other: &Self) -> Ordering {
+        unsafe {
+            self.as_key_ref().cmp(&other.as_key_ref())
+        }
+    }
+}
\ No newline at end of file
